<?php
// ##### Création du shortcode d'affichage d'un encart #####

function pg_encarts_creer_encart($atts) {
	// Extraction des attributs du shortcode
	$atts = shortcode_atts([
		'slug' => '',  // Slug du post à afficher
	], $atts, 'afficher_contenu_encart');

	// Vérification du slug
	if (empty($atts['slug'])) {
		return '<p>Veuillez spécifier un slug de post.</p>';
	}

	// Requête personnalisée pour récupérer l'encart
	$query = new WP_Query([
		'post_type' => 'encart',
		'name' => sanitize_text_field($atts['slug']),
		'posts_per_page' => 1,  // Un seul encart attendu
	]);

	ob_start();  // Démarrage de la capture de sortie
	// Vérification du résultat
	if ($query->have_posts()) {
		$query->the_post();
		the_content();  // Affichage du contenu de l'encart
	} else {
		echo '<p>Aucun contenu trouvé pour ' . esc_html($atts['slug']) . '.</p>';
	}

	wp_reset_postdata();  // Réinitialisation de la requête
	return ob_get_clean();  // Retourne le contenu capturé
}

// Enregistrement du shortcode
add_shortcode('afficher_contenu_encart', 'pg_encarts_creer_encart');

// Ajout d'une colonne "Shortcode" dans la liste des encarts
function pg_encarts_ajouter_colonne_shortcode($columns) {
	// Insère la colonne "Shortcode" juste après la colonne "Titre"
	$nouvelles_colonnes = [];
	foreach ($columns as $key => $value) {
		$nouvelles_colonnes[$key] = $value;
		if ($key === 'title') { // Repère la colonne "Titre"
			$nouvelles_colonnes['shortcode'] = __('Shortcode', 'pg-encarts');
		}
	}
	return $nouvelles_colonnes;
}
add_filter('manage_encart_posts_columns', 'pg_encarts_ajouter_colonne_shortcode');

// Remplit la colonne "Shortcode" pour chaque encart
function pg_encarts_afficher_contenu_colonne_shortcode($column, $post_id) {
	if ($column === 'shortcode') {
		$slug = get_post_field('post_name', $post_id); // Récupère le slug de l'encart
		echo '<code>[afficher_contenu_encart slug="' . esc_attr($slug) . '"]</code>'; // Affichage du shortcode
	}
}
add_action('manage_encart_posts_custom_column', 'pg_encarts_afficher_contenu_colonne_shortcode', 10, 2);
